=============================
Example for WSGI App
=============================

Setup
===========

::

 $ pip install uadetector

Run
===========

::

 $ python main.py

You can access http://127.0.0.1:8000. and get output like bellow.

::

 {
   "device_type": "pc",
   "os": "Mac OSX",
   "browser": "Chrome",
   "from_pc": true,
   "from_smartphone": true
 }
